@@ -1,7 +1,9 @@
 package Pod::Weaver::PluginBundle::Author::PERLANCAR;
 
-our $DATE = '2016-01-17'; # DATE
-our $VERSION = '0.26'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2016-12-10'; # DATE
+our $DIST = 'Pod-Weaver-PluginBundle-Author-PERLANCAR'; # DIST
+our $VERSION = '0.27'; # VERSION
 
 use 5.010001;
 
@@ -29,6 +31,7 @@ sub mvp_bundle_config {
         [ '@Author::PERLANCAR/postlude',  _exp('Region'), { region_name => 'postlude' } ],
 
         [ '@Author::PERLANCAR/Completion::GetoptLongComplete', _exp('Completion::GetoptLongComplete'), {} ],
+        [ '@Author::PERLANCAR/Completion::GetoptLongMore', _exp('Completion::GetoptLongMore'), {} ],
         [ '@Author::PERLANCAR/Completion::GetoptLongSubcommand', _exp('Completion::GetoptLongSubcommand'), {} ],
         [ '@Author::PERLANCAR/Completion::PerinciCmdLine', _exp('Completion::PerinciCmdLine'), {} ],
 
@@ -65,7 +68,7 @@ Pod::Weaver::PluginBundle::Author::PERLANCAR - PERLANCAR's default Pod::Weaver c
 
 =head1 VERSION
 
-This document describes version 0.26 of Pod::Weaver::PluginBundle::Author::PERLANCAR (from Perl distribution Pod-Weaver-PluginBundle-Author-PERLANCAR), released on 2016-01-17.
+This document describes version 0.27 of Pod::Weaver::PluginBundle::Author::PERLANCAR (from Perl distribution Pod-Weaver-PluginBundle-Author-PERLANCAR), released on 2016-12-10.
 
 =head1 SYNOPSIS
 
